'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Column = exports.Row = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enums = require('../enums');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Row component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var Row = exports.Row = function Row(props) {
  var className = (0, _utils.createClassName)(props.className || 'row', {
    'align-right': props.horizontalAlignment === _enums.HorizontalAlignments.RIGHT,
    'align-center': props.horizontalAlignment === _enums.HorizontalAlignments.CENTER,
    'align-justify': props.horizontalAlignment === _enums.HorizontalAlignments.JUSTIFY,
    'align-spaced': props.horizontalAlignment === _enums.HorizontalAlignments.SPACED,
    'align-top': props.verticalAlignment === _enums.VerticalAlignments.TOP,
    'align-middle': props.verticalAlignment === _enums.VerticalAlignments.MIDDLE,
    'align-bottom': props.verticalAlignment === _enums.VerticalAlignments.BOTTOM,
    'align-stretch': props.verticalAlignment === _enums.VerticalAlignments.STRETCH,
    'small-unstack': props.unstackOnSmall,
    'medium-unstack': props.unstackOnMedium,
    'large-unstack': props.unstackOnLarge,
    'small-collapse': props.collapseOnSmall,
    'medium-collapse': props.collapseOnMedium,
    'large-collapse': props.collapseOnLarge,
    'small-uncollapse': props.uncollapseOnSmall,
    'medium-uncollapse': props.uncollapseOnMedium,
    'large-uncollapse': props.uncollapseOnLarge,
    'collapse': props.isCollapsed,
    'column': props.isColumn,
    'expanded': props.isExpanded
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, props, { className: className }));
};

Row.propTypes = _extends({}, _utils.GeneralPropTypes, {
  horizontalAlignment: _react.PropTypes.string,
  verticalAlignment: _react.PropTypes.string,
  unstackOnSmall: _react.PropTypes.bool,
  unstackOnMedium: _react.PropTypes.bool,
  unstackOnLarge: _react.PropTypes.bool,
  collapseOnSmall: _react.PropTypes.bool,
  collapseOnMedium: _react.PropTypes.bool,
  collapseOnLarge: _react.PropTypes.bool,
  uncollapseOnSmall: _react.PropTypes.bool,
  uncollapseOnMedium: _react.PropTypes.bool,
  uncollapseOnLarge: _react.PropTypes.bool,
  isCollapsed: _react.PropTypes.bool,
  isColumn: _react.PropTypes.bool,
  isExpanded: _react.PropTypes.bool
});

/**
 * Column component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var Column = exports.Column = function Column(props) {
  var className = (0, _utils.createClassName)(props.className || 'columns', props.small ? 'small-' + props.small : null, props.medium ? 'medium-' + props.medium : null, props.large ? 'large-' + props.large : null, (0, _utils.objectHasValue)(props, 'offset.small') ? 'small-offset-' + props.offset.small : null, (0, _utils.objectHasValue)(props, 'offset.medium') ? 'medium-offset-' + props.offset.medium : null, (0, _utils.objectHasValue)(props, 'offset.large') ? 'large-offset-' + props.offset.large : null, (0, _utils.objectHasValue)(props, 'push.small') ? 'small-push-' + props.push.small : null, (0, _utils.objectHasValue)(props, 'push.medium') ? 'medium-push-' + props.push.medium : null, (0, _utils.objectHasValue)(props, 'push.large') ? 'large-push-' + props.push.large : null, (0, _utils.objectHasValue)(props, 'pull.small') ? 'small-pull-' + props.pull.small : null, (0, _utils.objectHasValue)(props, 'pull.medium') ? 'medium-pull-' + props.pull.medium : null, (0, _utils.objectHasValue)(props, 'pull.large') ? 'large-pull-' + props.pull.large : null, (0, _utils.objectHasValue)(props, 'up.small') ? 'small-up-' + props.up.small : null, (0, _utils.objectHasValue)(props, 'up.medium') ? 'medium-up-' + props.up.medium : null, (0, _utils.objectHasValue)(props, 'up.large') ? 'large-up-' + props.up.large : null, (0, _utils.objectHasValue)(props, 'order.small') ? 'small-order-' + props.order.small : null, (0, _utils.objectHasValue)(props, 'order.medium') ? 'medium-order-' + props.order.medium : null, (0, _utils.objectHasValue)(props, 'order.large') ? 'large-order-' + props.order.large : null, {
    'small-centered': props.centerOnSmall,
    'medium-centered': props.centerOnMedium,
    'large-centered': props.centerOnLarge,
    'small-uncentered': props.uncenterOnSmall,
    'medium-uncentered': props.uncenterOnMedium,
    'large-uncentered': props.uncenterOnLarge,
    'small-expand': props.expandOnSmall,
    'medium-expand': props.expandOnMedium,
    'large-expand': props.expandOnLarge,
    'shrink': props.isShrunk,
    'end': props.isLast
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, (0, _utils.removeProps)(props, ['offset']), { className: className }));
};

Column.propTypes = _extends({}, _utils.GeneralPropTypes, {
  small: _react.PropTypes.number,
  medium: _react.PropTypes.number,
  large: _react.PropTypes.number,
  offset: _react.PropTypes.object,
  push: _react.PropTypes.object,
  pull: _react.PropTypes.object,
  up: _react.PropTypes.object,
  order: _react.PropTypes.object,
  centerOnSmall: _react.PropTypes.bool,
  centerOnMedium: _react.PropTypes.bool,
  centerOnLarge: _react.PropTypes.bool,
  uncenterOnSmall: _react.PropTypes.bool,
  uncenterOnMedium: _react.PropTypes.bool,
  uncenterOnLarge: _react.PropTypes.bool,
  expandOnSmall: _react.PropTypes.bool,
  expandOnMedium: _react.PropTypes.bool,
  expandOnLarge: _react.PropTypes.bool,
  isShrunk: _react.PropTypes.bool,
  isLast: _react.PropTypes.bool
});